import { u as useRuntimeConfig, a as useStorage, d as defineEventHandler, r as readBody } from './nitro/node-server.mjs';
import { templateRender } from '@vue-email/compiler';
import 'node:http';
import 'node:https';
import 'fs';
import 'path';
import 'node:fs';
import 'node:url';

const storageKey = "assets:emails";
async function useCompiler(filename, data, verbose = false) {
  const vueEmailOptions = useRuntimeConfig().public.vueEmail;
  const source = await useStorage(storageKey).getItem(filename);
  const keys = await useStorage(storageKey).getKeys();
  const components = [];
  for (const key of keys) {
    const value = await useStorage(storageKey).getItem(key);
    if (value && key.endsWith(".vue")) {
      components.push({
        name: key,
        source: value
      });
    }
  }
  if (!source)
    throw new Error(`Template ${filename} not found`);
  const template = await templateRender(filename, { source, components }, data, {
    verbose,
    options: {
      baseUrl: vueEmailOptions?.baseUrl,
      i18n: vueEmailOptions?.i18n
    }
  });
  return template;
}

const generate_post = defineEventHandler(async (event) => {
  const payload = await readBody(event);
  const template = await useCompiler("Test.vue", {
    props: payload
  });
  return template;
});

export { generate_post as default };
//# sourceMappingURL=generate.post.mjs.map
